<?php
namespace Options\Form;

use Ep\InputFilter\InputFilter;
use Zend\Form\FieldsetInterface;
use Zend\Form\Form;
use Zend\InputFilter\InputFilterInterface;

/**
 * Obrazac za postavke.
 *
 * @package Options\Form
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/strig/options
 */
abstract class OptionsForm extends Form
{
    /**
     * Inicijalizira obrazac.
     */
    public function init()
    {
        parent::init();

        $class = $this->getAttribute('class');
        $class = explode(' ', $class);
        $class[] = 'form-horizontal';

        $this->setAttribute('class', implode(' ', $class));
        $this->setAttribute('novalidate', true);

        $this->add([
            'type' => 'hidden',
            'name' => 'option_name',
        ]);

        $this->add([
            'type' => 'hidden',
            'name' => 'form',
            'attributes' => [
                'value' => 'options_form',
            ],
        ]);

        $this->add([
            'type' => 'hidden',
            'name' => 'form_name',
        ]);

        $this->add([
            'type' => 'fieldset',
            'name' => 'option_value',
        ]);

        /** @var FieldsetInterface $fieldset */
        $fieldset = $this->get('option_value');
        $fieldsetFilter = new InputFilter();

        $this->addOptionFields($fieldset);
        $this->addOptionFilters($fieldsetFilter);

        $this->add([
            'type' => 'submit',
            'name' => 'submit',
            'options' => [
                'label' => 'Spremi promjene',
            ],
            'attributes' => [
                'class' => 'btn-primary',
            ],
        ], [
            'priority' => -1,
        ]);

        $formFilter = $this->getInputFilter();
        $formFilter->add($fieldsetFilter, 'option_value');
    }

    /**
     * Dodaje polja za ove postavke u obrazac.
     *
     * @param FieldsetInterface $fieldset
     */
    abstract function addOptionFields(FieldsetInterface $fieldset): void;

    /**
     * Dodaje input filter za postavke.
     *
     * @param InputFilterInterface $filter
     */
    abstract function addOptionFilters(InputFilterInterface $filter): void;
}