<?php
namespace Options\Middleware;

use Options\OptionsManager;
use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Psr\Http\Server\MiddlewareInterface;
use Psr\Http\Server\RequestHandlerInterface;
use Zend\Diactoros\Response\RedirectResponse;
use Zend\Expressive\Flash\FlashMessageMiddleware;
use Zend\Expressive\Flash\FlashMessagesInterface;

/**
 * Obrađuje obrasce s postavkama.
 *
 * @package Options\Middleware
 * @author Danijel Fabijan <hipnaba@gmail.com>
 * @link http://gitlab.ep.local/strig/options
 */
final class FormHandler implements MiddlewareInterface
{
    /** @var OptionsManager */
    private $manager;

    /**
     * Konstruktor.
     *
     * @param OptionsManager $manager
     */
    public function __construct(OptionsManager $manager)
    {
        $this->manager = $manager;
    }

    /**
     * Ako je postana forma s postavkama, obrađujemo ju.
     *
     * @param ServerRequestInterface $request
     * @param RequestHandlerInterface $handler
     *
     * @return ResponseInterface
     */
    public function process(ServerRequestInterface $request, RequestHandlerInterface $handler): ResponseInterface
    {
        if ($request->getMethod() !== 'POST' || ($request->getParsedBody()['form'] ?? '') !== 'options_form') {
            return $handler->handle($request);
        }

        $post = $request->getParsedBody();
        $option = $post['option_name'];

        $form = $this->manager->getForm($option);
        $form->setData($post);

        if ($form->isValid()) {
            $data = $form->getData();
            $this->manager->saveOption($data['option_name'], $data['option_value']);

            /** @var FlashMessagesInterface $messages */
            if ($messages = $request->getAttribute(FlashMessageMiddleware::FLASH_ATTRIBUTE)) {
                $messages->flash('options', 'Postavke spremljene!');
            }

            return new RedirectResponse($request->getServerParams()['REQUEST_URI']);
        }

        return $handler->handle($request);
    }
}